from abc import ABCMeta


class Analytic(metaclass=ABCMeta):
    """
    提供基于sql的查询分析服务
    """
